import 'dart:async';

import 'package:flutter_bloc/flutter_bloc.dart';

import 'package:hub/shared/components/molecules/menu/data/repositories/menu_repository_impl.dart';
import 'package:hub/shared/components/molecules/menu/index.dart';
import 'package:hub/shared/components/molecules/modules/index.dart';


class MenuViewEvent {}

class MenuViewState {
  final List<MenuItem?> menuEntries;
  final bool isGrid;

  MenuViewState({this.menuEntries = const [], this.isGrid = false});

  MenuViewState copyWith({List<MenuItem?>? menuEntries, bool? isGrid}) {
    return MenuViewState(
      menuEntries: menuEntries ?? this.menuEntries,
      isGrid: isGrid ?? this.isGrid,
    );
  }
}

class MenuViewBloc extends Bloc<MenuViewEvent, MenuViewState> {
  final MenuView style;
  final EnumMenuItem item;
  final List<MenuEntry> menuOptions;
  late StreamSubscription<void> _completer;


  MenuViewBloc({required this.style, required this.item, required this.menuOptions}) : super(MenuViewState()) {
    on<MenuViewEvent>((event, emit) async {
      await LicenseRemoteDataSourceImpl().waitForSaveCompletion();
      final entries = await MenuRepositoryImpl().generateMenuEntries(menuOptions, item);
      emit(state.copyWith(menuEntries: entries));
    });

    _completer = LicenseRemoteDataSourceImpl().streamCompleterController.listen((_) {
      add(MenuViewEvent());
    });
  }

  @override
  Future<void> close() {
    _completer.cancel();
    return super.close();
  }
  

}
